## v1.0.4 (16/08/2024)

- Improve sample code

## v1.0.3 (16/08/2024)

- Update documentation URL

## v1.0.2 (16/08/2024)

- Update README formatting

## v1.0.1 (16/08/2024)

- Update usage example

## v1.0.0 (16/08/2024)

- First release of `stitch-money-api`